@@ -33,6 +33,7 @@ from APTonCD.widgets.progresswindow import ProgressDialog
 from APTonCD.widgets import stepswidget
 from APTonCD.create.burnproperties import BurnProperties
 from APTonCD.create.finisheddialog import FinishedDialog
+from APTonCD.create.missingdialog import MissingDialog
 
 WINDOW_NAME = 'create'
     
@@ -45,6 +46,7 @@ class CreateWindow(controller.IController):
         """
             Constructor
         """
+        self.freespaceneeded = 0
         self.controller = controller
         self.glade = gui.get_glade(constants.CREATE_GUI, WINDOW_NAME)
         
@@ -69,6 +71,10 @@ class CreateWindow(controller.IController):
                 self.window.show()
             gui.setCursorToBusy(self.window, True)
         
+        self.tipBox = gui.get_widget(self.glade, 'tipbox')
+        self.btnCloseTipBox = gui.get_widget(self.glade, 'btnCloseTipBox')
+        self.btnMoreMissing = gui.get_widget(self.glade, 'btnMoreMissing')
+        
         self.ListContainer = gui.get_widget(self.glade,'ListContainer')       
         self.lblPkgDesc = gui.get_widget(self.glade, 'lblPkgDesc')
         self.pkgImg = gui.get_widget(self.glade, 'pkgImg')
@@ -121,6 +127,9 @@ class CreateWindow(controller.IController):
         self.__show_message(constants.MESSAGE_0001)
         self.packageList.clear()
         self.packageList.load_package_folder(self.packages_path, False, False)
+        if len(self.packageList.not_in_cache) > 0:
+            print "Note: there are some packages installed that are not available in cache"
+            #self.tipBox.show()
         #self.__show_message(constants.MESSAGE_0066)
         
     def get_main_window(self):
@@ -153,7 +162,14 @@ class CreateWindow(controller.IController):
         #gui.connect(self.ckbtnAutoSelectDepends, 'toggled', self.on_check)
         gui.connect(self.btnAdd, 'clicked', self.on_btnAdd_clicked)
         gui.connect(self.btnBurn,'clicked', self.on_btnBurn_clicked)
+        gui.connect(self.btnCloseTipBox, 'clicked', lambda x: self.tipBox.hide())
+        gui.connect(self.btnMoreMissing, 'clicked', self.on_missing)
     
+    def on_missing(self,widget):
+        missing = MissingDialog(self.controller, self.packageList.not_in_cache)
+        print missing.run()
+        missing.destroy()
+        
     def on_add_package(self,widget):
         
         file_add = filedialog.ChooseFileDialog(constants.MESSAGE_0013, self.window, constants.MESSAGE_0015, '*.deb')
@@ -179,7 +195,12 @@ class CreateWindow(controller.IController):
             self.values['isoname'] = burn_window.get_iso_name()
             self.values['createmeta'] = burn_window.get_metapackage()
             burn_window.destroy()
-            self.create_aptoncd()
+            destination_space = utils.get_free_space( self.values['destination'])
+            tmp_space = utils.get_free_space(self.temp_path)
+            if (tmp_space > (self.packageList.total_selected_size *2)) and (self.packageList.total_selected_size  < destination_space):
+                self.create_aptoncd()
+            else:
+                    gui.warn_message(constants.MESSAGE_0077 % ( self.temp_path,self.values['destination']))
         else:
             burn_window.destroy()
         
@@ -227,18 +248,15 @@ class CreateWindow(controller.IController):
 
             #if we are creating a metapackage
             #we must create a DEBIAN folder
-            
+            print 'Create Meta:', self.values['createmeta']
             if self.values['createmeta']:
                 utils.mkdir(utils.join_path(tmpmetapackageDir, 'DEBIAN'),True)
-            else:
-                utils.removePath(tmpmetapackageDir )
-
-            #metapackage configuration
-            if self.values['createmeta']:
                 controlFile =  utils.join_path(tmpmetapackageDir, 'DEBIAN/control')
                 utils.del_file(controlFile)
                 self.mPack = MetaPackage(controlFile)
-            
+            else:
+                utils.removePath(tmpmetapackageDir )
+                
             #cd destination folder
             destination = utils.join_path(tmppackages, media_folder_name)
             utils.mkdir(destination, True)
@@ -310,20 +328,27 @@ class CreateWindow(controller.IController):
             
             controlFile =  utils.join_path(tmpmetapackageDir, 'DEBIAN/control')
             #create the deb file for metapackage
-            command = 'dpkg-deb -b %s  %s > /dev/null 2> /dev/null' % \
-                      (tmpmetapackageDir.replace(' ','\ '), utils.join_path(pkg_destination.replace(' ','\ '), self.mPack.get_mtFileName()) )
-            result = utils.run_command(command)
-            #remove the file needed to create the metapackage
-            utils.del_file(controlFile)
+            if self.values['createmeta']:
+                command = 'dpkg-deb -b %s  %s > /dev/null 2> /dev/null' % \
+                        (tmpmetapackageDir.replace(' ','\ '), utils.join_path(pkg_destination.replace(' ','\ '), self.mPack.get_mtFileName()) )
+                result = utils.run_command(command)
+                #remove the file needed to create the metapackage
+                utils.del_file(controlFile)
             
             packages_files = utils.join_path(destination.replace(' ','\ ') , 'Packages')
             command = 'apt-ftparchive packages packages/'
-        
+            if self.progress.cancel_status:
+                errorMsg = constants.MESSAGE_0027
+                return False, errorMsg
+                    
             apt_ftp = AptFtpArchive()
             self.progress.stop = 100
             apt_ftp.set_progress_hook(self.on_update)
             apt_ftp.execute(command, destination, packages_files)
-            
+            if self.progress.cancel_status:
+                errorMsg = constants.MESSAGE_0027
+                return False, errorMsg
+                    
             #creates a tar file using bz2 compression
             result, path = utils.compress(packages_files)
             result, msg = utils.zip_file(utils.join_path(destination,'Packages.gz'), utils.join_path(destination,'Packages'))
@@ -332,12 +357,17 @@ class CreateWindow(controller.IController):
             command = 'apt-ftparchive release  .'
             apt_ftp.set_progress_hook(self.on_update)
             apt_ftp.execute(command, destination, packages_files)
-            
+            if self.progress.cancel_status:
+                errorMsg = constants.MESSAGE_0027
+                return False, errorMsg
+                    
             #Create aptoncd.inf file
             infoFile = utils.join_path(destination, 'aptoncd.info')
             info = mediainfo.MediaInfo(infoFile)
             info.write()
-            
+            if self.progress.cancel_status:
+                errorMsg = constants.MESSAGE_0027
+                return False, errorMsg
             #Creates .disk/info
             diskinfodir = utils.join_path(destination ,'.disk')
             utils.mkdir(diskinfodir, True)
@@ -361,9 +391,8 @@ class CreateWindow(controller.IController):
         return True, None
     
     def create_iso(self, isoFileList, tmpdir):
-        
+        self.progress.can_cancel_progress = False
         self.steps.set_current(2)
-        
         today = datetime.date.today().strftime('%Y%m%d')
         #this will hold all isos that we will create
         #from user selection
@@ -403,7 +432,6 @@ class CreateWindow(controller.IController):
             
             #now create the iso file
             command = ['-iso-level', '4' ,'-pad', '-l','-r', '-J', '-joliet-long', '-v', '-V', 'APTonCD', '-hide-rr-moved', '-o', finalDestiny.replace(' ','\ '),  destination.replace(' ','\ ')]
-            print command
             iso_file = Mkisofs()
             self.progress.stop = 100
             iso_file.set_progress_hook(self.progress.update_percent)
@@ -442,13 +470,20 @@ class CreateWindow(controller.IController):
             isoFileList = self.CreateIsoList(constants.CD)
         else:
             isoFileList = self.CreateIsoList(constants.DVD)
-        
         #we will starting changing here to break process in parts
         # first, copy files from cds to locations
         
         result, msg = self.copy_files(isoFileList,tmpdir)
-        self.scan_packages(isoFileList,tmpdir)
-
+        # the user clicked cancel button
+        if not result :
+            self.get_main_window().set_sensitive(True)
+            return False
+            
+        result, msg = self.scan_packages(isoFileList,tmpdir)
+        if not result :
+            self.get_main_window().set_sensitive(True)
+            return False 
+        
         self.create_iso(isoFileList,tmpdir)
         
         self.steps.set_current(3)
@@ -511,7 +546,7 @@ class CreateWindow(controller.IController):
                         cds[currentCD] = []
                 cds[currentCD].append(pkg)
                 actualSize += pkg.size
-                
+                self.freespaceneeded += pkg.size
         return cds
     
     def get_packages_size(self):
