@@ -36,10 +36,15 @@ def TreeViewSearch( model, column, key, it, data):
     """
         Do case insensitive wildcard search on package name.
     """
-    key = key.lower()
-    title = model.get_value(it, COL_PACKAGE).package
-    title = title.lower()
-    return title.find(key) == -1
+    try:
+        key = key.lower()
+        print model 
+        title = model.get_value(it, COL_PACKAGE).package
+        title = title.lower()
+        return title.find(key) == -1
+    except Exception,  e:
+        print str(e)
+        return False 
 
 class PackageView(gtk.TreeView):
     """This class represent the package list in the main window"""
@@ -56,6 +61,7 @@ class PackageView(gtk.TreeView):
 
         #packages dictionary for fast search of a package
         self.packages = {}
+        self.not_in_cache = []
 
         #packages selection options
         self.select_old = False # allow old packages selection
@@ -344,7 +350,12 @@ class PackageView(gtk.TreeView):
 
         self.store.uncheck_minor_version()
         #self.count_packages()
-
+        
+        for n in self.store.installed.keys():
+            if not self.store.get_package(n):
+                self.not_in_cache.append(n)
+        
+        print len(self.not_in_cache)
         progress.set_fraction(0)
         progress.hide()
         progress.set_text('0%')
@@ -589,7 +600,6 @@ class PackageModel(gtk.ListStore):
             current_str = package.CurrentVer.VerStr
             name = package.Name
             self.installed[name] = current_str
-        print 'got installed'
 
     def __create_package(self, package_name, path_to_scan, custom = False):
         """
